# coding: utf-8

# flake8: noqa

"""
    MaaS

    MaaS (Matomat as a Service) API definition  # noqa: E501

    OpenAPI spec version: 0.5.2
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from __future__ import absolute_import

# import apis into sdk package
from swagger_client.api.auth_api import AuthApi
from swagger_client.api.items_api import ItemsApi
from swagger_client.api.service_api import ServiceApi
from swagger_client.api.users_api import UsersApi

# import ApiClient
from swagger_client.api_client import ApiClient
from swagger_client.configuration import Configuration
# import models into sdk package
from swagger_client.models.auth_success import AuthSuccess
from swagger_client.models.error import Error
from swagger_client.models.item import Item
from swagger_client.models.item_stats import ItemStats
from swagger_client.models.service_stats import ServiceStats
from swagger_client.models.service_stats_items import ServiceStatsItems
from swagger_client.models.service_stats_items_cost import ServiceStatsItemsCost
from swagger_client.models.service_stats_users import ServiceStatsUsers
from swagger_client.models.service_stats_users_credits import ServiceStatsUsersCredits
from swagger_client.models.transferred_credits import TransferredCredits
from swagger_client.models.user import User
from swagger_client.models.user_stats import UserStats
