# coding: utf-8

"""
    MaaS

    MaaS (Matomat as a Service) API definition  # noqa: E501

    OpenAPI spec version: 0.5.2
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from __future__ import absolute_import

import unittest

import swagger_client
from swagger_client.api.items_api import ItemsApi  # noqa: E501
from swagger_client.rest import ApiException


class TestItemsApi(unittest.TestCase):
    """ItemsApi unit test stubs"""

    def setUp(self):
        self.api = swagger_client.api.items_api.ItemsApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_items_get(self):
        """Test case for items_get

        List all available items  # noqa: E501
        """
        pass

    def test_items_item_id_consume_patch(self):
        """Test case for items_item_id_consume_patch

        Consumes a Item  # noqa: E501
        """
        pass

    def test_items_item_id_delete(self):
        """Test case for items_item_id_delete

        Delete Item  # noqa: E501
        """
        pass

    def test_items_item_id_get(self):
        """Test case for items_item_id_get

        Get a certain Item  # noqa: E501
        """
        pass

    def test_items_item_id_patch(self):
        """Test case for items_item_id_patch

        Update Item  # noqa: E501
        """
        pass

    def test_items_item_id_stats_get(self):
        """Test case for items_item_id_stats_get

        Get consumption stats  # noqa: E501
        """
        pass

    def test_items_post(self):
        """Test case for items_post

        Add a new item  # noqa: E501
        """
        pass

    def test_items_stats_get(self):
        """Test case for items_stats_get

        Get consumption stats of all items  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()
