# coding: utf-8

"""
    MaaS

    MaaS (Matomat as a Service) API definition  # noqa: E501

    OpenAPI spec version: 0.5.2
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from __future__ import absolute_import

import unittest

import swagger_client
from swagger_client.api.auth_api import AuthApi  # noqa: E501
from swagger_client.rest import ApiException


class TestAuthApi(unittest.TestCase):
    """AuthApi unit test stubs"""

    def setUp(self):
        self.api = swagger_client.api.auth_api.AuthApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_auth_login_post(self):
        """Test case for auth_login_post

        Logs a user in and returns an JWT token for authentication  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()
