# coding: utf-8

"""
    MaaS

    MaaS (Matomat as a Service) API definition  # noqa: E501

    OpenAPI spec version: 0.5.2
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from __future__ import absolute_import

import unittest

import swagger_client
from swagger_client.models.service_stats_items import ServiceStatsItems  # noqa: E501
from swagger_client.rest import ApiException


class TestServiceStatsItems(unittest.TestCase):
    """ServiceStatsItems unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testServiceStatsItems(self):
        """Test ServiceStatsItems"""
        # FIXME: construct object with mandatory attributes with example values
        # model = swagger_client.models.service_stats_items.ServiceStatsItems()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()
